@@ -2,7 +2,7 @@
 Cucumber result to Jira Xray Test repository
 
 """
-__version__ = "0.5.12"
+__version__ = "0.5.13"
 
 
 import datetime
@@ -69,6 +69,7 @@ class CuJiraX:
             self, 
             cucumber_json: str,
             import_result=True, 
+            import_testcase=True,
             ignore_duplicate=True
         )-> dict:
 
@@ -88,15 +89,6 @@ class CuJiraX:
                     description=self.testexecution_desc or f.description or "TBA"
                 ),
             ]
-
-            # Import Test cases
-            exists, new = self._split_elements_to_exist_and_new(
-                elements=f.elements, 
-                j=self.jira, 
-                ignore_duplicate=ignore_duplicate
-            )
-            
-            tests = [str(n) for n in map(lambda x: self._update_description_if_exist(x,self.jira), exists)]
             output.update({
                 'test_set': str(ticket_ts),
                 'testset_name': testset_name,
@@ -104,14 +96,27 @@ class CuJiraX:
                 'test_execution': str(ticket_te),
                 'testexecution_name': testexecution_name,
                 'test_plan': self.result_info.testPlanKey,
-                'existing_tests': tests,
                 'test_environments': self.result_info.testEnvironments
             })
 
-            logger.info(output)
-            
-            test_cases = [n for n in map(lambda x: self._new_testcase(x, self.jira_project, ticket_ts, self.parent_testset_key), new)]
-            test.bulk_import(test_cases) if test_cases else None
+            # Import Test cases
+            if import_testcase:
+                exists, new = self._split_elements_to_exist_and_new(
+                    elements=f.elements, 
+                    j=self.jira, 
+                    ignore_duplicate=ignore_duplicate
+                )
+                
+                tests = [str(n) for n in map(
+                    lambda x: self._update_description_if_exist(x,self.jira), exists)]
+                output.update({
+                    'existing_tests': tests,
+                })
+
+                logger.info(output)
+                
+                test_cases = [n for n in map(lambda x: self._new_testcase(x, self.jira_project, ticket_ts, self.parent_testset_key), new)]
+                test.bulk_import(test_cases) if test_cases else None
             
             # Import Results
             if import_result:
@@ -151,7 +156,8 @@ class CuJiraX:
         for el in elements:
             test_name = cls.scenarioid_to_tescasename(el.id, el.keyword)
             tests = j.get_tests(test_name)
-            assert tests, "Test not created: {}".format(test_name)
+            if not tests:
+                raise ValueError("Test not created: {}".format(test_name))
             
             test_key = tests[0]
             if not ignore_duplicate:
